/*
 * absolute.h - Main absolute driver declarations
 * Copyright (C) 2005 Ian Gulliver
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <inttypes.h>

struct devrec {
   char *device;
   char *calibration_file;
   enum {
	   UNKNOWN,
	   USB_HID_TOUCHSCREEN
   } subdriver;
   struct point *points;
   struct mapping *mappings;
   void (*read_function)(int, struct devrec *);
   void (*init_function)(int, struct devrec *);
   int_least32_t minX;
   int_least32_t minY;
   int_least32_t maxX;
   int_least32_t maxY;
   int_least32_t minZ;
   int_least32_t maxZ;
   int_least32_t minButtonZ;
   int park;
   int parked;
   int_least32_t parkX;
   int_least32_t parkY;
   int switchxy;
   int allowdrag;
   int_least32_t x;
   int_least32_t y;
   int_least32_t z;
   uint_least8_t button; /* bitfield */
   uint_least8_t ignorebutton; /* bitfield */
   uint_least8_t discardbutton; /* bitfield */
   uint_least8_t fakebutton; /* bitfield */
   int buttonZ;
   int tty_fd;
};

void absolute_move_x(struct devrec *priv, int_least32_t x);
void absolute_move_y(struct devrec *priv, int_least32_t y);
void absolute_move_z(struct devrec *priv, int_least32_t z);
void absolute_button_down(struct devrec *priv, int button);
void absolute_button_up(struct devrec *priv, int button);
