/*
 * convert.h - Coordinate system conversion declarations
 * Copyright (C) 2005 Ian Gulliver
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <inttypes.h>

struct point {
	int_least32_t Ax;
	int_least32_t Ay;
	int_least32_t Bx;
	int_least32_t By;
	struct point *next;
};

struct mapping {
	uint_least16_t id;
	struct point *point1;
	struct point *point2;
	int_least32_t X_offset;
	int_least32_t Y_offset;
	double X_scale;
	double Y_scale;
	struct mapping *next;
};

struct point *add_point(struct point *old, int_least32_t Ax, int_least32_t Ay, int_least32_t Bx, int_least32_t By);
struct mapping *build_mappings(struct point *head);

struct point *load_points(char *filename);

void convert(struct mapping *mappings, struct point *point);

void free_points(struct point *iter);
void free_mappings(struct mapping *iter);
