/*
 * linux_event.c - Linux input event interface driver definitions
 * Copyright (C) 2005 Ian Gulliver
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <linux/input.h>

#include "xf86Module.h"
#include "absolute.h"
#include "linux_event.h"

void linux_event_read(int fd, struct devrec *devrec) {
	struct input_event packet;

	while (read(fd,&packet,sizeof(packet)) == sizeof(packet)) {
		switch (packet.type) {
			case EV_ABS:
				switch (packet.code) {
					case ABS_X:
						absolute_move_x(devrec,packet.value);
						break;
					case ABS_Y:
						absolute_move_y(devrec,packet.value);
						break;
					case ABS_Z:
						absolute_move_z(devrec,packet.value);
						break;
				}
				break;
			case EV_KEY:
				switch (packet.code) {
					case BTN_LEFT:
					case BTN_0:
					case BTN_TOUCH:
						if (packet.value & 0x01)
							absolute_button_down(devrec,0);
						else
							absolute_button_up(devrec,0);
						break;
					case BTN_MIDDLE:
					case BTN_1:
						if (packet.value & 0x01)
							absolute_button_down(devrec,1);
						else
							absolute_button_up(devrec,1);
						break;
					case BTN_RIGHT:
					case BTN_2:
						if (packet.value & 0x01)
							absolute_button_down(devrec,2);
						else
							absolute_button_up(devrec,2);
						break;
				}
				break;
		}
	}
}
