/*
 * linux_usb_hid.c - Linux USB HID interface driver definitions
 * Copyright (C) 2005 Ian Gulliver
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "xf86Module.h"
#include "absolute.h"
#include "linux_usb_hid.h"

/* copied from kernel source Documentation/usb/hiddev.txt */
struct packet {
	unsigned event;
	signed int value;
};

#define EVENT_PRESS 852034
#define EVENT_X_COORD 65584
#define EVENT_Y_COORD 65585
#define EVENT_Z_COORD 852016

void linux_usb_hid_read(int fd, struct devrec *devrec) {
	struct packet packet;
	int i;

	while (read(fd,&packet,sizeof(packet)) == sizeof(packet)) {
		switch (packet.event) {
			case EVENT_PRESS:
				for (i = 0; i < 4; i++) {
					if (packet.value & (0x01 << i))
						absolute_button_down(devrec,i);
					else
						absolute_button_up(devrec,i);
				}
				break;
			case EVENT_X_COORD:
				absolute_move_x(devrec,packet.value);
				break;
			case EVENT_Y_COORD:
				absolute_move_y(devrec,packet.value);
				break;
			case EVENT_Z_COORD:
				absolute_move_z(devrec,packet.value);
				break;
		}
	}
}
