/*
 * magictouch_serial.c - MagicTouch serial interface driver definitions
 * Copyright (C) 2005 Ian Gulliver
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include "xf86Module.h"
#include "absolute.h"
#include "magictouch_serial.h"

#define FLAG_TOUCH 0x40
#define FLAG_BUTTON1 0x01
#define FLAG_BUTTON2 0x02
#define FLAG_BUTTON3 0x04
#define FLAG_SYSINFO 0x08

struct packet {
	unsigned char flags;
	unsigned char x[2];
	unsigned char y[2];
};

void magictouch_serial_init(int fd, struct devrec *devrec) {
	write(fd,"I",1);
}

void magictouch_serial_read(int fd, struct devrec *devrec) {
	struct packet packet;

	while (read(fd,&packet,sizeof(packet)) == sizeof(packet)) {
		if (packet.flags & FLAG_SYSINFO)
			continue;
		absolute_move_x(devrec,packet.x[1] + ((int_least16_t) packet.x[0] << 7));
		absolute_move_y(devrec,packet.y[1] + ((int_least16_t) packet.y[0] << 7));

		if (packet.flags & FLAG_TOUCH)
			absolute_button_down(devrec,0);
		else
			absolute_button_up(devrec,0);

		if (packet.flags & FLAG_BUTTON1)
			absolute_button_down(devrec,1);
		else
			absolute_button_up(devrec,1);

		if (packet.flags & FLAG_BUTTON2)
			absolute_button_down(devrec,2);
		else
			absolute_button_up(devrec,2);

		if (packet.flags & FLAG_BUTTON3)
			absolute_button_down(devrec,3);
		else
			absolute_button_up(devrec,3);
	}
}
